betty.ancestry.has_citations module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.has_citations module

Tools to build data types have citations.

class betty.ancestry.has_citations.HasCitations

  Bases: `Entity`

  An entity with citations that support it.

  __init__(*args: Any, citations: Iterable[Citation] | ToManyResolver[Citation] | None = None, **kwargs: Any)
  citations

    A bidirectional *-to-many entity type association.